View source: R/feature_selection.R
| find_variable_events | R Documentation |
Calculate the Sum Deviance for Inclusion and Exclusion Matrices
find_variable_events(
m1_matrix,
m2_matrix = NULL,
min_row_sum = 50,
n_threads = 1,
verbose = FALSE,
...
)
m1_matrix |
A matrix representing the inclusion matrix. Rows are events, columns are barcodes. |
m2_matrix |
A matrix representing the exclusion matrix. Rows are events, columns are barcodes. |
min_row_sum |
A numeric value specifying the minimum row sum threshold for filtering events. Defaults to 50. |
n_threads |
If the module OpenPM is available for your device, the function suggests using multi-thread processing for even faster computation. |
verbose |
Logical. If |
... |
Additional arguments to be passed. |
A data.table containing the events and their corresponding sum deviance values.
# loading the toy dataset
toy_obj <- load_toy_M1_M2_object()
# getting HVE (high variable events)
HVE <- find_variable_events(toy_obj$m1, toy_obj$m2)
# printing the results
print(HVE[order(-sum_deviance)])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.